# Generated by Django 3.0.6 on 2020-05-14 15:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bridger", "0010_asset_content_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="asset", name="file_url_name", field=models.CharField(blank=True, max_length=1024, null=True),
        ),
    ]
