# Generated by Django 3.0.6 on 2020-05-14 15:05
import uuid

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bridger", "0006_auto_20200507_0913"),
    ]

    operations = [
        migrations.CreateModel(
            name="Asset",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False,),),
                ("file", models.FileField(upload_to="markdown/assets")),
            ],
            options={"verbose_name": "Asset", "verbose_name_plural": "Assets",},
        ),
    ]
