# Generated by Django 3.0.6 on 2020-05-14 15:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bridger", "0008_auto_20200514_1711"),
    ]

    operations = [
        migrations.RenameModel(old_name="Asset111", new_name="Asset",),
    ]
